@@ -379,6 +379,104 @@ def lookup_element_shannon_radius_data(symbol, copy=True):
 
         return None
 
+# Loader and cache for the machine-learned extended element Shannon radii datasets.
+
+_element_shannon_radii_data_extendedML = None
+
+
+def lookup_element_shannon_radius_data_extendedML(symbol, copy=True):
+    """
+    Retrieve the machine learned extended Shannon radii for 
+    known states of an element.
+
+
+    Retrieve Shannon radii for known oxidation states and coordination
+    environments of an element.
+
+    Source of extended radii is:
+    Baloch, A.A., Alqahtani, S.M., Mumtaz, F., Muqaibel, A.H., Rashkeev,
+    S.N. and Alharbi, F.H., 2021. 
+    Extending Shannon's Ionic Radii Database Using Machine Learning.
+    arXiv preprint arXiv:2101.00269.
+
+    Args:
+        symbol (str) : the atomic symbol of the element to look up.
+
+        copy (Optional(bool)): if True (default), return a copy of the data
+        dictionary, rather than a reference to the cached object --
+        only use copy=False in performance-sensitive code and where
+        you are certain the dictionary will not be modified!
+
+    Returns:
+        list:
+            Extended Shannon radii datasets.
+
+        Returns None if the element was not found among the external
+        data.
+
+        Shannon radii datasets are dictionaries with the keys:
+
+        charge
+            *int* charge
+        coordination
+            *int* coordination
+        ionic_radius
+            *float*
+        comment
+            *str*
+    """
+
+    global _element_shannon_radii_data_extendedML
+
+    if _element_shannon_radii_data_extendedML is None:
+        _element_shannon_radii_data_extendedML = {}
+
+        with open(os.path.join(data_directory, "shannon_radii_ML_extended.csv"),
+                  'r') as file:
+            reader = csv.reader(file)
+
+            # Skip the first row (headers).
+
+            next(reader)
+
+            for row in reader:
+                # For the shannon radii, there are multiple datasets for
+                # different element/oxidation-state/coordination
+                # combinations.
+
+                key = row[0]
+
+                dataset = {
+                    'charge': int(row[1]),
+                    'coordination': row[2],
+                    'crystal_radius': float(row[3]),
+                    'ionic_radius': float(row[4]),
+                    'comment': row[5]
+                    }
+
+                if key in _element_shannon_radii_data_extendedML:
+                    _element_shannon_radii_data_extendedML[key].append(dataset)
+                else:
+                    _element_shannon_radii_data_extendedML[key] = [dataset]
+
+    if symbol in _element_shannon_radii_data_extendedML:
+        if copy:
+            # _element_shannon_radii_data_extendedML stores a list of dictionaries
+            # -> if copy is set, copy the list and use the dict.copy()
+            # function on each element.
+            # The dictionary values are all Python "value types", so
+            # nothing further is required to make a deep copy.
+            return [item.copy() for item in
+                    _element_shannon_radii_data_extendedML[symbol]]
+        else:
+            return _element_shannon_radii_data_extendedML[symbol]
+    else:
+        if _print_warnings:
+            print("WARNING: Extended Shannon-radius data for element {0} not "
+                  "found.".format(symbol))
+
+        return None
+
 # Loader and cache for the element solid-state energy (SSE) datasets.
 
 _element_ssedata = None
